@@ -1033,6 +1033,13 @@ static int check_access(sbcontext_t * sbcontext, const char *func, const char *p
 			result = 1;
 			goto out;
 		}
+
+		/* If we are here, and still no joy, and its the access() call,
+		 * do not log it, but just return -1 */
+		if (0 == strncmp(func, "access_rd", 7)) {
+			sbcontext->show_access_violation = 0;
+			goto out;
+		}
 	}
 		
 	if ((0 == strncmp(func, "access_wr", 7)) ||
@@ -1135,6 +1142,13 @@ unlink_hack_end:
 			sbcontext->show_access_violation = 0;
 			goto out;
 		}
+
+		/* If we are here, and still no joy, and its the access() call,
+		 * do not log it, but just return -1 */
+		if (0 == strncmp(func, "access_wr", 7)) {
+			sbcontext->show_access_violation = 0;
+			goto out;
+		}
 	}
 
 out:
@@ -1149,11 +1163,11 @@ static int check_syscall(sbcontext_t * sbcontext, const char *func, const char *
 	char buffer[512];
 	char *absolute_path = NULL;
 	char *resolved_path = NULL;
-	char *log_path = NULL;
+	char *log_path = NULL, *debug_log_path = NULL;
 	int old_errno = errno;
 	int result = 1;
-	int log_file = 0;
-	int debug = 0;
+	int log_file = 0, debug_log_file = 0;
+	int access = 0, debug = 0, verbose = 1;
 	int color = ((getenv("NOCOLOR") != NULL) ? 0 : 1);
 
 	init_wrappers();
@@ -1165,29 +1179,41 @@ static int check_syscall(sbcontext_t * sbcontext, const char *func, const char *
 	if (NULL == resolved_path)
 		goto fp_error;
 
-	if (NULL == getenv("SANDBOX_DEBUG")) {
-		log_path = getenv("SANDBOX_LOG");
-	} else {
-		log_path = getenv("SANDBOX_DEBUG_LOG");
-		debug = 1;
+	log_path = getenv("SANDBOX_LOG");
+	if (NULL != getenv("SANDBOX_DEBUG")) {
+		if ((0 == strncasecmp(getenv("SANDBOX_DEBUG"), "1", 1)) ||
+		    (0 == strncasecmp(getenv("SANDBOX_DEBUG"), "yes", 3))) {
+			debug_log_path = getenv("SANDBOX_DEBUG_LOG");
+			debug = 1;
+		}
+	}
+
+	if (NULL != getenv("SANDBOX_VERBOSE")) {
+		if ((0 == strncasecmp(getenv("SANDBOX_VERBOSE"), "0", 1)) ||
+		    (0 == strncasecmp(getenv("SANDBOX_VERBOSE"), "no", 2)))
+			verbose = 0;
 	}
 
 	result = check_access(sbcontext, func, absolute_path, resolved_path);
 
-	if ((0 == result) && (1 == sbcontext->show_access_violation)) {
-		EERROR(color, "ACCESS DENIED", "  %s:%*s%s\n",
-			func, (int)(10 - strlen(func)), "", absolute_path);
-	} else if ((1 == debug) && (1 == sbcontext->show_access_violation)) {
-		EINFO(color, "ACCESS ALLOWED", "  %s:%*s%s\n",
-			func, (int)(10 - strlen(func)), "", absolute_path);
-	} else if ((1 == debug) && (0 == sbcontext->show_access_violation)) {
-		EWARN(color, "ACCESS PREDICTED", "  %s:%*s%s\n",
-			func, (int)(10 - strlen(func)), "", absolute_path);
+	if (1 == verbose) {
+		if ((0 == result) && (1 == sbcontext->show_access_violation)) {
+			EERROR(color, "ACCESS DENIED", "  %s:%*s%s\n",
+				func, (int)(10 - strlen(func)), "", absolute_path);
+		} else if ((1 == debug) && (1 == sbcontext->show_access_violation)) {
+			EINFO(color, "ACCESS ALLOWED", "  %s:%*s%s\n",
+				func, (int)(10 - strlen(func)), "", absolute_path);
+		} else if ((1 == debug) && (0 == sbcontext->show_access_violation)) {
+			EWARN(color, "ACCESS PREDICTED", "  %s:%*s%s\n",
+				func, (int)(10 - strlen(func)), "", absolute_path);
+		}
 	}
 
-	if ((NULL != log_path) &&
-	    (((0 == debug) && (0 == result) && (1 == sbcontext->show_access_violation)) ||
-	     (1 == debug))) {
+	if ((0 == result) && (1 == sbcontext->show_access_violation))
+		access = 1;
+
+	if (((NULL != log_path) && (1 == access)) ||
+	    ((NULL != debug_log_path) && (1 == debug))) {
 		if (0 != strncmp(absolute_path, resolved_path, strlen(absolute_path))) {
 			sprintf(buffer, "%s:%*s%s (symlink to %s)\n", func,
 					(int)(10 - strlen(func)), "",
@@ -1197,18 +1223,36 @@ static int check_syscall(sbcontext_t * sbcontext, const char *func, const char *
 					(int)(10 - strlen(func)), "",
 					absolute_path);
 		}
-		if ((0 == lstat(log_path, &log_stat)) &&
-		    (0 == S_ISREG(log_stat.st_mode))) {
-			EERROR(color, "SECURITY BREACH", "  '%s' %s\n", log_path,
-				"already exists and is not a regular file!");
-		} else {
-			check_dlsym(open);
-			log_file = true_open(log_path, O_APPEND | O_WRONLY |
-					O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP |
-					S_IROTH);
-			if (log_file >= 0) {
-				write(log_file, buffer, strlen(buffer));
-				close(log_file);
+		if (1 == access) {
+			if ((0 == lstat(log_path, &log_stat)) &&
+			    (0 == S_ISREG(log_stat.st_mode))) {
+				EERROR(color, "SECURITY BREACH", "  '%s' %s\n", log_path,
+					"already exists and is not a regular file!");
+			} else {
+				check_dlsym(open);
+				log_file = true_open(log_path, O_APPEND | O_WRONLY |
+						O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP |
+						S_IROTH);
+				if (log_file >= 0) {
+					write(log_file, buffer, strlen(buffer));
+					close(log_file);
+				}
+			}
+		} 
+		if (1 == debug) {
+			if ((0 == lstat(debug_log_path, &log_stat)) &&
+			    (0 == S_ISREG(log_stat.st_mode))) {
+				EERROR(color, "SECURITY BREACH", "  '%s' %s\n", debug_log_path,
+					"already exists and is not a regular file!");
+			} else {
+				check_dlsym(open);
+				debug_log_file = true_open(debug_log_path, O_APPEND | O_WRONLY |
+						O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP |
+						S_IROTH);
+				if (debug_log_file >= 0) {
+					write(debug_log_file, buffer, strlen(buffer));
+					close(debug_log_file);
+				}
 			}
 		}
 	}
